DESCRIPTION="The libxfce4util package is a basic utility library for the Xfce desktop environment."

EXT_VERSION=$(basename $PKG_BLANK .tar.gz | cut -d "-" -f 2) 

./configure --prefix=/usr &&
make

# As root:
make install

update_version_list $PKG_BLANK
